<?php

/*

    Gavintech Framework - A base for PHP projects
    Copyright (C) 2004-2008 Chris Kloosterman

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

class RssFeed {

	private $xml;
	private $title_xslt;
	private $entry_xslt;

	function __construct($url) {
		$xml_text = file_get_contents($url);
		
		$this->xml = new DOMDocument();
		$this->xml->loadXML($xml_text);

		$this->setupXslt();
	}

	function getTitle() {
		$xslproc = new XSLTprocessor();
		$xslproc->importStylesheet($this->title_xslt);
		return trim($xslproc->transformToXML($this->xml));
	}

	function getEntries() {
		$xslproc = new XSLTprocessor();
		$xslproc->importStylesheet($this->entry_xslt);
		return trim($xslproc->transformToXML($this->xml));
	}

	function setupXslt() {
		$title_xslt_text = <<<END_OF_TITLE
		
<xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" version = "1.0" xmlns:dc="http://purl.org/dc/elements/1.1/" >
        <xsl:output method = "text" />

        <xsl:template match="/*[1]">
                <xsl:value-of select="*[1]/*[local-name()='title']"/>
        </xsl:template>

</xsl:stylesheet>

END_OF_TITLE;

		$this->title_xslt = new DOMDocument();
		$this->title_xslt->loadXML($title_xslt_text);
	
		$entry_xslt_text = <<<END_OF_ENTRY
		
<xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" version = "1.0" >
        <xsl:output method = "text"/>

        <xsl:template match="/*[1]">
                <xsl:for-each select="//*[local-name()='item']">
                        <xsl:value-of select="substring(normalize-space(*[local-name()='title']), 0, 100)"/>
                        <xsl:text> || </xsl:text>
                        <xsl:value-of select="*[local-name()='link']"/>
			<xsl:if test="*[local-name()='description']">
	                        <xsl:text> || </xsl:text>
		                <xsl:value-of select="substring(normalize-space(*[local-name()='description']), 0, 200)"/>
			</xsl:if>
                        <xsl:text>|||</xsl:text>
                </xsl:for-each>

        </xsl:template>

</xsl:stylesheet>

END_OF_ENTRY;

		$this->entry_xslt = new DOMDocument();
		$this->entry_xslt->loadXML($entry_xslt_text);
	

	}
}

?>
