<?php

/*

    Gavintech Framework - A base for PHP projects
    Copyright (C) 2004-2008 Chris Kloosterman

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# These are the cleaning functions that should be used on all user input

function clean_form_neutral($data) {
        return $data;
}

function clean_sql_neutral($data) {
        return $data;
}

function clean_neutral_form($data) {
        $data = htmlentities($data, ENT_COMPAT, "UTF-8");
        return $data;
}

function clean_neutral_sql($data, $database=DEFAULT_DATABASE) {
        $data=sql_escape($data, $database);
        return $data;
}

function clean_neutral_url($data) {
        $data=urlencode($data);
        return $data;
}

function clean_neutral_display($data) {
        $data=htmlentities($data, ENT_COMPAT, "UTF-8");
        $data=nl2br($data);
        return $data;
}

/*
 * clean_form_display
 *
 * clean and filter data from a form so that we can use it on pages
 *
 * $data the variable to clean
 *
 */

function clean_form_display($data) {
        $data=htmlentities($data);
        $data=nl2br($data);
        return $data;
}

/*
 * clean_sql_display
 *
 * clean and filter data from a form so that we can use it on pages
 *
 * $data the variable to clean
 *
 */

function clean_sql_display($data) {
        $data=htmlentities($data);
        $data=nl2br($data);
        return $data;
}

/*
 * clean_sql_form
 *
 * clean and filter data from a form so that we can use it in a form
 *
 * $data the variable to clean
 *
 */

function clean_sql_form($data) {
        $data=htmlentities($data);
        return $data;
}

/*
 * clean_form_sql
 *
 * clean and filter data from a form so that we can insert it into the database
 *
 * $data the variable to clean
 *
 */

function clean_form_sql($data, $database=DEFAULT_DATABASE) {
        $data=html_entity_decode($data);
	$data=sql_escape($data, $database);
        return $data;
}

/*
 * clean_sql_sql
 *
 * clean and filter data from a database so that we can insert it into the database
 *
 * $data the variable to clean
 *
 */

function clean_sql_sql($data, $database=DEFAULT_DATABASE) {
	$data=sql_escape($data, $database);
        return $data;
}

/*
 * clean_form_form
 *
 * clean and filter data from a form so that we use it in another html form
 *
 * $data the variable to clean
 *
 */

function clean_form_form($data) {
        $data=html_entity_decode($data);
        $data=htmlentities($data);
        return $data;
}

/*
 * clean_form_url
 *
 * clean and filter data from a form so that we use it in a url
 *
 * $data the variable to clean
 *
 */

function clean_form_url($data) {
        $data=html_entity_decode($data);
        $data=urlencode($data);
        return $data;
}

/*
 * clean_sql_url
 *
 * clean and filter data from a database so that we use it in a url
 *
 * $data the variable to clean
 *
 */

function clean_sql_url($data) {
        $data=urlencode($data);
        return $data;
}

?>
