<?php

/*

    Gavintech Framework
    Copyright (C) 2004-2007 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

/////////////////
// Date functions
/////////////////

/*
 * display_date_dropdown
 *
 * display a range of dropdown boxes based on the time passed in
 * what dropdowns are displayed are dependant on granularity
 *
 * $time - the unix timestamp of the date that should be displayed
 * $name - the name of the array
 * $granularity - which boxes to display: date, time, both
 * $return - whether to return or print the dropdown (default print)
 * $start_year - the first year to display in the dropdown box
 * $end_year - the last year to display in the dropdown box
 *
 */

function display_date_dropdown ($time, $name, $granularity, $return = false, $start_year = 'ns', $end_year = 'ns', $onChange = '', $show_no_date = false) {

        # get the actual numbers
        $day = date("j",$time);
        $month = date("n",$time);
        $year = date("Y",$time);
        $hour = date("G",$time);
        $minute = date("i",$time);

	# set the start and end year if they're not passed in
	if ($start_year == 'ns') {
		$start_year = 1970;
	}
	if ($end_year == 'ns') {
		$end_year = date("Y", time()) + 10;
	}

        if ($granularity == "date" || $granularity == "both" || $granularity == "month") {
                # display the date
		if ($granularity != "month") {
			$ret .= "<select name=\"".$name."[day]\" id=\"".$name."_day\" onChange=\"$onChange\">\n";
			if ($show_no_date) {
				$ret .= "<option value=\"-1\">no date</option>\n";
			}
			for ($i = 1; $i <=31; $i++) {
				$selected = ($i == $day && $time > 0)
					? " selected=\"selected\""
					: $selected = "";
				$ret .= "<option$selected value=\"$i\">$i</option>\n";
			}
			$ret .= "</select>-";
		}
                $ret .= "<select name=\"".$name."[month]\" id=\"".$name."_month\" onChange=\"$onChange\">\n";
		if ($show_no_date) {
			$ret .= "<option value=\"-1\">no date</option>\n";
		}
                for ($i = 1; $i <=12; $i++) {
                        $selected = ($i == $month && $time > 0)
                                ? " selected=\"selected\""
                                : $selected = "";
                        $ret .= "<option$selected value=\"$i\">".
                                # get the month string for a month number
                                date("F",mktime(1,1,1,$i,1,1)).
                                "</option>\n";
                }
                $ret .= "</select>-";
                $ret .= "<select name=\"".$name."[year]\" id=\"".$name."_year\" onChange=\"$onChange\">\n";
		if ($show_no_date) {
			$ret .= "<option value=\"-1\">no date</option>\n";
		}
                for ($i = $start_year; $i <= $end_year; $i++) {
                        $selected = ($i == $year && $time > 0)
                                ? " selected=\"selected\""
                                : $selected = "";
                        $ret .= "<option$selected value=\"$i\">$i</option>\n";
                }
                $ret .= "</select>";
        }
        if ($granularity == "both") {
                # we need a space between the dropdowns
                $ret .= "&nbsp;&nbsp;";
        }

        if ($granularity == "time" || $granularity == "both") {
                # display the time
                $ret .= "<select name=\"".$name."[hour]\" id=\"".$name."_hour\" onChange=\"$onChange\">\n";
		if ($show_no_date) {
			$ret .= "<option value=\"-1\">no date</option>\n";
		}
                for ($i = 0; $i <=23; $i++) {
                        $selected = ($i == $hour && $time > 0)
                                ? " selected=\"selected\""
                                : $selected = "";
                        $ret .= "<option$selected value=\"$i\">$i</option>\n";
                }
                $ret .= "</select>:";
                $ret .= "<select name=\"".$name."[minute]\" id=\"".$name."_minute\" onChange=\"$onChange\">\n";
		if ($show_no_date) {
			$ret .= "<option value=\"-1\">no date</option>\n";
		}
                for ($i = 0; $i <=59; $i++) {
                        $selected = ($i == $minute && $time > 0)
                                ? " selected=\"selected\""
                                : $selected = "";
                        $ret .= "<option$selected value=\"$i\">".str_pad($i,2,"0",STR_PAD_LEFT)."</option>\n";
                }
                $ret .= "</select>";
        }

	if ($return == true) {
		return $ret;
	} else {
		print $ret;
	}
}
?>
