<?php

/*

    Gavintech Framework - A base for PHP projects
    Copyright (C) 2004-2008 Chris Kloosterman

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# This script contains the functions that could be called
# from more than one place, and are used in more
# than one place in the code.

# function: puke
# input: $error: the error message
# return: none
# description: an unrecoverable error has occured, die gracefully
function puke($error) {
	# include the header and sidebar if they haven't been printed
	load("header.php");
	load("sidebar.php");
	# print the error
?>
<div class="error">
<h1>Error!</h1>
<p>An unrecoverable error occured in the page you were trying to view.  The error is:</p>
<p><?php echo($error); ?></p>
</div>
<?php

	# hide the password
	if ($_POST["password"]) {
		$_POST["password"] = "(hidden)";
	}
	if (IS_PRODUCTION) {
		$message = "Debug info:

Stack Trace:
".print_r(debug_backtrace(),true)."

Get Variables
".print_r($_GET,true)."

Post Variables
".print_r($_POST,true)."

Session Variables
".print_r($_SESSION,true)."

IP: ".$_SERVER["REMOTE_ADDR"]."

Server: ".$_SERVER["SERVER_NAME"];

		mail (PUKE_EMAIL, FRAMEWORK_NAME." Puke", $message, "From: ".PUKE_FROM);
		echo ("<p>An administrator has been notified about this error.</p>");
	} else {
		# print useful debugging info
		echo("<h1>Stack Trace</h1><pre>");
		print_r(debug_backtrace());
		echo("</pre>");
		echo("<h1>Get variables</h1><pre>");
		print_r($_GET);
		echo("</pre>");
		echo("<h1>Post variables</h1><pre>");
		print_r($_POST);
		echo("</pre>");
		echo("<h1>Session variables</h1><pre>");
		print_r($_SESSION);
		echo("</pre>");
	}

	# footer
	load("footer.php");
	exit();
}

# function: print_errors
# input: none
# return: none
# description: print the errors and warnings generated for a page
function print_errors() {
	
	global $errors;
	global $warnings;
	global $successes;

	# print out the errors, all nice and pretty
	if (count($errors) > 0) {
		echo ("<div class=\"error\">");
		echo ("<h2>Error!</h2>");
		echo ("<p>The following errors were encountered:</p>\n<p>");
		# print each error in the array on its own line
		echo ("<ul>");
		foreach ($errors as $error) {
			echo ("<li>".$error."</li>");
		}
		echo ("</ul>");
		echo ("</div>");

		# don't print successes if we errored
		$successes = array();
	}
	
	# same thing now with the warnings
	if (count($warnings) > 0) {
		echo ("<div class=\"error\">");
		echo ("<h2>Warning!</h2>");
		# print each warning in the array on its own line
		echo ("<ul>");
		foreach ($warnings as $warning) {
			echo ("<li>".$warning."</li>");
		}
		echo ("</ul>");
		echo ("</div>");

		# don't print successes if we errored
		$successes = array();
	}

	# same thing now with the successes
	if (count($successes) > 0) {
		echo ("<div class=\"success\">");
		echo ("<h2>Success!</h2>");
		# print each success in the array on its own line
		echo ("<ul>");
		foreach ($successes as $success) {
			echo ("<li>".$success."</li>");
		}
		echo ("</ul>");
		echo ("</div>");
	}

}

function require_validator($validator) {
	if (VALIDATOR != $validator) {
		puke("Form was not validated with $validator");
	}
}

function debug_print($line) {
	if (DEBUG) {
		print $line;
	}
}

?>
