<?php

/*

    Gavintech Framework
    Copyright (C) 2004-2007 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

require_once("MDB2.php");

# this script provides wrappers for all of the database functions

function &sql_connect($host, $user, $password, $database, $readwrite="read") {

	if (DEBUG) {
		echo ("<p>Connecting to database $database (".DATABASE_TYPE.") for $readwrite</p>");
	}

	global $db_links;

	if (!isset($db_links[$readwrite][$database])) {
		$dsn = DATABASE_TYPE."://$user:$password@$host/$database?charset=utf8";

		$options_array = array();

		if (DATABASE_TYPE == "mysql" or DATABASE_TYPE == "mysqli") {
			$options_array["default_table_type"] = "INNODB";
		}

		$db_link =& MDB2::factory($dsn, $options_array);
		if (PEAR::isError($db_link)) {
			puke("Could not connect to database: ".$db_link->getMessage());
		}
		$db_link->setCharset("utf8");
		$db_link->loadModule('Extended');
		$db_links[$readwrite][$database] = $db_link;
	}

	return $db_links[$readwrite][$database];
}

function sql_select_db($database,$db_link) {
	echo ("<p><b>Warning:</b>Sql_select_db no longer supported, create another connection instead!</p>");
}

function sql_query($sql) {
	echo ("<p><b>Warning:</b>Sql_query no longer supported, use sql_build_manip and sql_execute_manip instead!</p>");
}

function sql_query_read($sql, $database=DEFAULT_DATABASE, $limit_start=NULL, $limit_count=NULL) {

	$db_link = sql_get_db_link($database, "read");

	# figure out whether we should use the query cache
	$query_cache = array();
	if (DO_CACHING == "true" && !defined('DO_CACHING_OVERRIDE')) {
		global $query_cache;
	}
	
	# debug print the SQL statement
	if (DEBUG) {
		echo ("<p>Read SQL Query: ".$sql);
	}

	if ($limit_start != NULL || $limit_count != NULL) {
		if ($limit_start == NULL) {
			$limit_start = 0;
		}
		if ($limit_count == NULL) {
			$limit_count = 10;
		}

		# these get executed differently because of the limits
		if ($query_cache[$sql][$limit_start][$limit_count]) {
			if ($query_cache[$sql][$limit_start][$limit_count]->numRows() > 0) {
				$query_cache[$sql][$limit_start][$limit_count]->seek(0);
			}
			if (DEBUG) {
				echo (" <b>cache hit</b></p>");
			}
			global $total_cached_sql_queries;
			$total_cached_sql_queries++;
			return $query_cache[$sql][$limit_start][$limit_count];
		} else {
			if (DEBUG) {
				echo (" <b>cache miss</b></p>");
			}

			$db_link->setLimit($limit_count, $limit_start);

			$result = $db_link->query($sql);
			if (PEAR::isError($result)) {
				puke("Error: ".$result->getMessage());
			} else {
				$query_cache[$sql][$limit_start][$limit_count] = $result;
				global $total_sql_queries;
				$total_sql_queries++;
				return $result;
			}
		}

	} else {
		if ($query_cache[$sql]["all"]) {
			if ($query_cache[$sql]["all"]->numRows() > 0) {
				$query_cache[$sql]["all"]->seek(0);
			}
			if (DEBUG) {
				echo (" <b>cache hit</b></p>");
			}
			global $total_cached_sql_queries;
			$total_cached_sql_queries++;
			return $query_cache[$sql]["all"];
		} else {
			if (DEBUG) {
				echo (" <b>cache miss</b></p>");
			}
			$result = $db_link->query($sql);
			if (PEAR::isError($result)) {
				puke("Error: ".$result->getMessage());
			} else {
				$query_cache[$sql]["all"] = $result;
				global $total_sql_queries;
				$total_sql_queries++;
				return $result;
			}
		}
	}
}

function sql_query_write($sql, $database=DEFAULT_DATABASE) {
	# you probably shouldn't be using this function unless you're writing a migration and need to run some DDL

	$db_link = sql_get_db_link($database, "write");

	# debug print the SQL statement
	if (DEBUG) {
		echo ("<p>Write SQL Query: ".$sql);
	}

	$result = $db_link->query($sql);
	if (PEAR::isError($result)) {
		puke("Error: ".$result->getMessage());
	} else {
		global $total_sql_queries;
		$total_sql_queries++;
		return $result;
	}
}

function sql_fetch_array($result) {
	return($result->fetchRow(MDB2_FETCHMODE_ASSOC));
}

function sql_fetch_assoc($result) {
	return sql_fetch_array($result);
}

function sql_fetch_row($result) {
	return sql_fetch_array($result);
}

function sql_num_rows($result) {
	return $result->numRows();
}

function sql_insert_id($sequence=NULL, $database=DEFAULT_DATABASE) {
	echo ("<p><b>Warning:</b>You should be using sequences now, so this should be unnecessary</p>");
}

function sql_affected_rows($db_link="") {
	global $affected_rows;
	return $affected_rows;
}

function sql_start_transaction($database=DEFAULT_DATABASE) {
	if (DEBUG) {
		echo ("<p>Starting a transaction for $database</p>");
	}
	$db_link = sql_get_db_link($database, "write");
	$result = $db_link->beginTransaction();
	if (PEAR::isError($result)) {
		puke ("Start trans error: ".$result->getMessage());
	}
}

function sql_rollback($database=DEFAULT_DATABASE) {
	if (DEBUG) {
		echo ("<p>Rolling back transaction for $database</p>");
	}
	$db_link = sql_get_db_link($database, "write");
	$result = $db_link->rollback();
	if (PEAR::isError($result)) {
		puke ("Start trans error: ".$result->getMessage());
	}
}

function sql_commit($database=DEFAULT_DATABASE) {
	if (DEBUG) {
		echo ("<p>Committing transaction for $database</p>");
	}
	$db_link = sql_get_db_link($database, "write");
	$result = $db_link->commit();
	if (PEAR::isError($result)) {
		puke ("Start trans error: ".$result->getMessage());
	}
}

function sql_build_manip($table, $fields, $mode, $where, $database=DEFAULT_DATABASE) {
	$db_link = sql_get_db_link($database, "write");
	$sql = $db_link->buildManipSQL($table, $fields, $mode, $where);

	if (PEAR::isError($sql)) {
		puke("Could not build a manipulation query!");
	}

	if (DEBUG) {
		echo ("<p>Built a manipulation query: $sql</p>");
	}
	# MDB2_PREPARE_MANIP means that the execute will return the number of affected rows
	$stmt = $db_link->prepare($sql, NULL, MDB2_PREPARE_MANIP);

	if (PEAR::isError($stmt)) {
		puke("Could not build a manipulation query!");
	}

	return $stmt;
}

function sql_execute_manip($stmt, $fields, $log_this = true) {
	global $affected_rows;
	if (DEBUG) {
		echo ("<p>Executing manipulation query with args ".join(",",$fields)."</p>");
	}
	$affected_rows = $stmt->execute($fields);
	if (PEAR::isError($affected_rows)) {
		if ($affected_rows->getMessage() == "MDB2 Error: constraint violation") {
			global $errors;
			$errors[] = "You cannot modify this record, as it breaks data integrity.  Please make sure that there is nothing linked to this data first, and then try deleting it again.";
			return false;
		} else {
			puke("Prepared statement failed: ".$affected_rows->getMessage());
		}
	} else {
		if ($log_this && $affected_rows > 0) {
			# snag the query before it gets updated below
			$query = $stmt->db->last_query;
			add_log($query, "SQL Log", FRAMEWORK_LOG_DEBUG);
		}
	}
	return true;
}

function &sql_get_db_link($database, $readwrite) {

	if ($readwrite == "write") {
		# check to make sure we're not read-only
		if (READ_ONLY_MODE == true) {
			echo ("<p class=\"error\">Read only mode.  Skipping query.</p>");
			return null;
		}
	}

	global $db_links;
	if (!isset($db_links["write"][$database])) {
		puke("Not connected to $database for writes!");
	} else {
		$db_link = $db_links["write"][$database];
	}

	return $db_link;

}

# sequences are always named ($table)_seq (but the MDB2 library appends _seq)
function sql_next_id($table, $database=DEFAULT_DATABASE) {
	$db_link = sql_get_db_link($database, "write");
	return $db_link->nextID($table, true);
}

function sql_escape($data, $database=DEFAULT_DATABASE) {
	$db_link = sql_get_db_link($database, "write");
	return $db_link->quote($data);
}

function sql_quote_identifier($data, $database=DEFAULT_DATABASE) {
	$db_link = sql_get_db_link($database, "read");
	return $db_link->quoteIdentifier($data);
}

?>
